4Suite API Documentation: Ft.Lib.Regex

4Suite™ API Documentation

# ► Module Ft.Lib.Regex

Tools to manage the many different flavors of regex

    Copyright 2004 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Functions: W3cRegexToPyRegex |  |  |  | Globals: MIN_LENGTH_SEQ_PAT

## Functions

W3cRegexToPyRegex(w3cregex)
  Convert W3C regex to Python regex e.g.: >>> from Ft.Lib.Regex import W3cRegexToPyRegex >>> print repr(W3cRegexToPyRegex(u"(foo){5,}")) u'((foo)){5}(foo)*'

## Globals

MIN_LENGTH_SEQ_PAT = <_sre.SRE_Pattern object>
  Compiled regular expression objects